@@ -45,7 +45,7 @@ def mine_logs(dir):
     return git_result
 
 def mine_stats(commit_hash, gitObj=None, isMerge=False, sleep_amount=0):
-    if isMerge:
+    if gitObj is not None and isMerge:
         time.sleep(sleep_amount)
         commit = gitObj.get_commit(sha=commit_hash) 
         return [
@@ -62,7 +62,7 @@ def get_log(args):
     # attempt to read the git log from the user specified directory, if it fails, notify them and leave the function
     if args.directory:
         try:
-            create_json(mine_logs(args.directory), args.directory, args.github_token)
+            create_json(mine_logs(args.directory), args.directory, args.github_token, no_merge=args.no_merge)
             return
         except Exception as ex:
             print(ex)
@@ -78,7 +78,7 @@ def get_log(args):
                     # no exception is handeled here, since only the previously extracted directories are being opened
                     # hidden directories are ignored
                     if dir[0] != '.':
-                        create_json(mine_logs(args.multiple_directories + '/' + dir), args.multiple_directories + '/' + dir, args.github_token, dir)
+                        create_json(mine_logs(args.multiple_directories + '/' + dir), args.multiple_directories + '/' + dir, args.github_token, dir, no_merge=args.no_merge)
                 return
 
         except Exception as ex:
@@ -88,13 +88,13 @@ def get_log(args):
 
 
 # process the mined data and store it in JSON
-def create_json(git_log_result, current_path, Github_token=None, attempted_directory=None):
+def create_json(git_log_result, current_path, Github_token=None, attempted_directory=None, no_merge=False):
     logParser = GitLogParser()
     try:
         logParser.parse_lines(git_log_result)
         #the update data extraction is a separate function, since it assumes that every commit has aleady been mined
         if Github_token:
-            logParser.get_update_data(current_path, Github_token)
+            logParser.get_update_data(current_path, Github_token, no_merge)
     except models.UnexpectedLineError as ex:
         if 'fatal: not a git repository' in str(ex):
             if attempted_directory:
@@ -117,7 +117,7 @@ class GitLogParser(object):
     #def commit_sort(self, e):
     #    return e.commit_date
 
-    def get_update_data(self, location, github_token):
+    def get_update_data(self, location, github_token, no_merge):
         #saves the home directory
         base_dir = os.getcwd()
 
@@ -129,10 +129,11 @@ class GitLogParser(object):
         #opens the target dir, mines it then returns the result
         os.chdir(location)
 
-        url = subprocess.getoutput('git config --get remote.origin.url').split('.')[1]
-        url = list(filter(None, url.split('/')))
-        url = url[-2] + '/' + url[-1] 
-        repo = Github(github_token).get_repo(url)
+        if not no_merge:
+            url = subprocess.getoutput('git config --get remote.origin.url').split('.')[1]
+            url = list(filter(None, url.split('/')))
+            url = url[-2] + '/' + url[-1] 
+            repo = Github(github_token).get_repo(url)
 
         #get the stats on multple threads to increase performance
         # the number of workers is specified as the number of cpus*5, this is the current default, however for the future it is safer this way
@@ -144,13 +145,14 @@ class GitLogParser(object):
             sleep_time = 0
             for i in range(len(self.commits)-2, -1, -1):
                 # since the git api allows 5000 requests per hour a sleep is reuqired
-                if self.commits[i].isMerge:
+                # if the -nm handle is specified the merge results will not be accurate, but the parser will finish quicker
+                if self.commits[i].isMerge and not no_merge:
                     results.append(executor.submit(mine_stats, self.commits[i].commit_hash, repo, self.commits[i].isMerge,sleep_time))
                     # when calculating the sleep time, I expect the worst case possible, meaning that every process is making an API call
                     if sleep_time < multiprocessing.cpu_count() * MAX_INVERVAL * 5:
                         sleep_time = sleep_time + MAX_INVERVAL
                 else:
-                    results.append(executor.submit(mine_stats, self.commits[i].commit_hash, repo, self.commits[i].isMerge))
+                    results.append(executor.submit(mine_stats, self.commits[i].commit_hash, isMerge=self.commits[i].isMerge))
         
             #this is needed since the commits are in a different order then the results
             current_commit = len(self.commits)-2
@@ -158,10 +160,16 @@ class GitLogParser(object):
             print('Getting diff data')
             for r in progressbar.progressbar(results):
                 if self.commits[current_commit].isMerge:
-                    resultList = r.result()
-                    self.commits[current_commit].files_changed = resultList[0]
-                    self.commits[current_commit].insertions = resultList[1]
-                    self.commits[current_commit].deletions = resultList[2]
+                    #resultList = r.result()
+                    if no_merge:
+                        self.commits[current_commit].files_changed = 0
+                        self.commits[current_commit].insertions = 0
+                        self.commits[current_commit].deletions = 0
+                    else:
+                        resultList = r.result()
+                        self.commits[current_commit].files_changed = resultList[0]
+                        self.commits[current_commit].insertions = resultList[1]
+                        self.commits[current_commit].deletions = resultList[2]
                 else:
                     stat_dict = dict()
                     # since the result method stop the code until the thread finishes, we don't have to wait for the results to come in anywhere else
