@@ -95,7 +95,8 @@ def test_dummy_commit_singleDir():
     class dummyArgs(object):
         def __init__(self, dir):
             self.directory = dir
-            self.github_token = None
+            self.github_token = 'None'
+            self.no_merge = True
     subprocess.run('git clone https://github.com/gaborantal/git-log-parser.git', cwd='./tests', shell=True)
     subprocess.run('git checkout 86e684ddfb16f98f09211bb8087b6d321b25c145', cwd='./tests/git-log-parser', shell=True)
     args = dummyArgs('./tests/git-log-parser')
@@ -111,7 +112,8 @@ def test_dummmy_commit_mDir():
         def __init__(self, dir):
             self.directory = None
             self.multiple_directories = dir
-            self.github_token = None
+            self.github_token = 'None'
+            self.no_merge = True
     args = dummyArgs('./tests')
     parser.get_log(args)
     with open('./tests/correct_result.json', 'r', encoding='utf-8') as f:
